@@ -34,23 +34,21 @@
 
 #define CAMEL_EXCHANGE_SUMMARY_VERSION (2)
 
-#define EXTRACT_FIRST_DIGIT(val) val=strtoul (part, &part, 10);
-#define EXTRACT_DIGIT(val) part++; val=strtoul (part, &part, 10);
-#define EXTRACT_FIRST_STRING(val) len=strtoul (part, &part, 10); if (*part) part++; val=g_strndup (part, len); part+=len;
-#define EXTRACT_STRING(val) if (*part) part++; len=strtoul (part, &part, 10); if (*part) part++; val=g_strndup (part, len); part+=len;
-
 #define d(x)
 
 G_DEFINE_TYPE (CamelExchangeSummary, camel_exchange_summary, CAMEL_TYPE_FOLDER_SUMMARY)
 
 static gboolean
-exchange_summary_check_for_trash (CamelFolder *folder)
+exchange_summary_check_for_trash (CamelFolder *folder,
+                                  GCancellable *cancellable)
 {
 	CamelStore *parent_store;
 	CamelFolder *trash;
 
 	parent_store = camel_folder_get_parent_store (folder);
-	trash = camel_store_get_trash (parent_store, NULL);
+
+	trash = camel_store_get_trash_folder_sync (
+		parent_store, cancellable, NULL);
 
 	if (trash == NULL)
 		return FALSE;
@@ -61,6 +59,7 @@ exchange_summary_check_for_trash (CamelFolder *folder)
 static gboolean
 exchange_summary_expunge_mail (CamelFolder *folder,
                                CamelMessageInfo *info,
+                               GCancellable *cancellable,
                                GError **error)
 {
 	GPtrArray *uids = g_ptr_array_new ();
@@ -75,7 +74,8 @@ exchange_summary_expunge_mail (CamelFolder *folder,
 	g_ptr_array_add (uids, uid);
 
 	success = camel_exchange_utils_expunge_uids (
-		CAMEL_SERVICE (parent_store), full_name, uids, error);
+		CAMEL_SERVICE (parent_store),
+		full_name, uids, cancellable, error);
 
 	g_ptr_array_free (uids, TRUE);
 
@@ -103,7 +103,7 @@ exchange_summary_header_load (CamelFolderSummary *summary,
 		return -1;
 
 	/* Old summary file - We need to migrate.  Migration automagically happens when
-	   camel_folder_summary_save is called
+	 * camel_folder_summary_save is called
 	*/
 	if (camel_file_util_decode_uint32 (in, &high_article_num) == -1) {
 		if (version > CAMEL_EXCHANGE_SUMMARY_VERSION)
@@ -111,7 +111,7 @@ exchange_summary_header_load (CamelFolderSummary *summary,
 	}
 
 	/* During migration we will not have high_article_num stored in the summary and
-	   essentially we will end up computing it atleast once.
+	 * essentially we will end up computing it atleast once.
 	*/
 	exchange->readonly = readonly;
 	exchange->high_article_num = high_article_num;
@@ -163,7 +163,7 @@ exchange_summary_message_info_migrate (CamelFolderSummary *summary,
 
 	info = folder_summary_class->message_info_migrate (summary, in);
 	if (info) {
-		einfo = (CamelExchangeMessageInfo *)info;
+		einfo = (CamelExchangeMessageInfo *) info;
 
 		if (camel_file_util_decode_string (in, &thread_index) == -1)
 			goto error;
@@ -174,7 +174,7 @@ exchange_summary_message_info_migrate (CamelFolderSummary *summary,
 			g_free (thread_index);
 
 		/* Old summary file - We need to migrate.  Migration automagically happens when
-		   camel_folder_summary_save is called
+		 * camel_folder_summary_save is called
 		*/
 		if (camel_file_util_decode_string (in, &href) == -1) {
 			if (CAMEL_EXCHANGE_SUMMARY (summary)->version > CAMEL_EXCHANGE_SUMMARY_VERSION)
@@ -207,7 +207,7 @@ exchange_summary_message_info_new_from_header (CamelFolderSummary *summary,
 	if (!info)
 		return info;
 
-	einfo = (CamelExchangeMessageInfo *)info;
+	einfo = (CamelExchangeMessageInfo *) info;
 	thread_index = camel_header_raw_find (&h, "Thread-Index", NULL);
 	if (thread_index)
 		einfo->thread_index = g_strdup (thread_index + 1);
@@ -225,7 +225,7 @@ exchange_summary_message_info_free (CamelFolderSummary *summary,
 	folder_summary_class = CAMEL_FOLDER_SUMMARY_CLASS (
 		camel_exchange_summary_parent_class);
 
-	einfo = (CamelExchangeMessageInfo *)info;
+	einfo = (CamelExchangeMessageInfo *) info;
 
 	g_free (einfo->href);
 	g_free (einfo->thread_index);
@@ -271,17 +271,9 @@ exchange_summary_summary_header_from_db (CamelFolderSummary *s,
 
 	part = mir->bdata;
 
-	if (part) {
-		EXTRACT_FIRST_DIGIT (exchange->version)
-	}
-
-	if (part) {
-		EXTRACT_DIGIT (exchange->readonly)
-	}
-
-	if (part) {
-		EXTRACT_DIGIT (exchange->high_article_num)
-	}
+	exchange->version = bdata_extract_digit (&part);
+	exchange->readonly = bdata_extract_digit (&part);
+	exchange->high_article_num = bdata_extract_digit (&part);
 
 	return 0;
 }
@@ -290,7 +282,7 @@ static CamelMIRecord *
 exchange_summary_message_info_to_db (CamelFolderSummary *s,
                                      CamelMessageInfo *info)
 {
-	CamelExchangeMessageInfo *einfo = (CamelExchangeMessageInfo *)info;
+	CamelExchangeMessageInfo *einfo = (CamelExchangeMessageInfo *) info;
 	CamelFolderSummaryClass *folder_summary_class;
 	struct _CamelMIRecord *mir;
 
@@ -318,10 +310,9 @@ exchange_summary_message_info_from_db (CamelFolderSummary *s,
 	info = folder_summary_class->message_info_from_db (s, mir);
 	if (info) {
 		gchar *part = mir->bdata;
-		gint len;
-		einfo = (CamelExchangeMessageInfo *)info;
-		EXTRACT_FIRST_STRING (einfo->thread_index)
-		EXTRACT_FIRST_STRING (einfo->href)
+		einfo = (CamelExchangeMessageInfo *) info;
+		einfo->thread_index = bdata_extract_string (&part);
+		einfo->href = bdata_extract_string (&part);
 	}
 
 	return info;
@@ -350,29 +341,29 @@ exchange_summary_info_set_flags (CamelMessageInfo *info,
 	folder_summary_class = CAMEL_FOLDER_SUMMARY_CLASS (
 		camel_exchange_summary_parent_class);
 
-	if (offline_store->state != CAMEL_OFFLINE_STORE_NETWORK_UNAVAIL) {
+	if (!camel_offline_store_get_online (offline_store)) {
 		if (folder && info->uid) {
 			if ((flags & set & CAMEL_MESSAGE_DELETED) &&
-			    exchange_summary_check_for_trash (folder)) {
-				return exchange_summary_expunge_mail (folder, info, NULL);
+			    exchange_summary_check_for_trash (folder, NULL)) {
+				return exchange_summary_expunge_mail (folder, info, NULL, NULL);
 			} else {
 				camel_exchange_utils_set_message_flags (
 					CAMEL_SERVICE (parent_store),
 					full_name, info->uid, set, flags, NULL);
-				return folder_summary_class->info_set_flags(info, flags, set);
+				return folder_summary_class->info_set_flags (info, flags, set);
 			}
 		}
 	}
 	else {
 		if (folder && info->uid) {
 			if ((flags & set & CAMEL_MESSAGE_DELETED) &&
-			    exchange_summary_check_for_trash (folder)) {
+			    exchange_summary_check_for_trash (folder, NULL)) {
 				/* FIXME: should add a separate journal entry for this case. */ ;
 			} else {
 				CamelExchangeFolder *exchange_folder = (CamelExchangeFolder *) folder;
 				CamelExchangeJournal *journal = (CamelExchangeJournal *) exchange_folder->journal;
 				camel_exchange_journal_delete (journal, info->uid, flags, set, NULL);
-				return folder_summary_class->info_set_flags(info, flags, set);
+				return folder_summary_class->info_set_flags (info, flags, set);
 			}
 		}
 	}
@@ -393,7 +384,7 @@ exchange_summary_info_set_user_tag (CamelMessageInfo *info,
 	folder_summary_class = CAMEL_FOLDER_SUMMARY_CLASS (
 		camel_exchange_summary_parent_class);
 
-	res = folder_summary_class->info_set_user_tag(info, name, value);
+	res = folder_summary_class->info_set_user_tag (info, name, value);
 	if (res && info->summary->folder && info->uid) {
 		CamelFolder *folder = info->summary->folder;
 		CamelStore *parent_store;
@@ -446,7 +437,8 @@ camel_exchange_summary_init (CamelExchangeSummary *summary)
  * Return value: the summary object.
  **/
 CamelFolderSummary *
-camel_exchange_summary_new (struct _CamelFolder *folder, const gchar *filename)
+camel_exchange_summary_new (struct _CamelFolder *folder,
+                            const gchar *filename)
 {
 	CamelFolderSummary *summary;
 	GError *local_error = NULL;
@@ -494,7 +486,7 @@ camel_exchange_summary_get_readonly (CamelFolderSummary *summary)
  **/
 void
 camel_exchange_summary_set_readonly (CamelFolderSummary *summary,
-				     gboolean readonly)
+                                     gboolean readonly)
 {
 	CamelExchangeSummary *es;
 
@@ -531,7 +523,7 @@ camel_exchange_summary_get_article_num (CamelFolderSummary *summary)
  **/
 void
 camel_exchange_summary_set_article_num (CamelFolderSummary *summary,
-					guint32 article_num)
+                                        guint32 article_num)
 {
 	CamelExchangeSummary *es;
 
@@ -555,34 +547,34 @@ camel_exchange_summary_set_article_num (CamelFolderSummary *summary,
  **/
 void
 camel_exchange_summary_add_offline (CamelFolderSummary *summary,
-				    const gchar *uid,
-				    CamelMimeMessage *message,
-				    CamelMessageInfo *info)
+                                    const gchar *uid,
+                                    CamelMimeMessage *message,
+                                    CamelMessageInfo *info)
 {
 	CamelMessageInfoBase *mi;
 	const CamelFlag *flag;
 	const CamelTag *tag;
 
 	/* Create summary entry */
-	mi = (CamelMessageInfoBase *)camel_folder_summary_info_new_from_message (summary, message, NULL);
+	mi = (CamelMessageInfoBase *) camel_folder_summary_info_new_from_message (summary, message, NULL);
 
 	/* Copy flags 'n' tags */
-	mi->flags = camel_message_info_flags(info);
+	mi->flags = camel_message_info_flags (info);
 
-	flag = camel_message_info_user_flags(info);
+	flag = camel_message_info_user_flags (info);
 	while (flag) {
-		camel_message_info_set_user_flag((CamelMessageInfo *)mi, flag->name, TRUE);
+		camel_message_info_set_user_flag ((CamelMessageInfo *) mi, flag->name, TRUE);
 		flag = flag->next;
 	}
-	tag = camel_message_info_user_tags(info);
+	tag = camel_message_info_user_tags (info);
 	while (tag) {
-		camel_message_info_set_user_tag((CamelMessageInfo *)mi, tag->name, tag->value);
+		camel_message_info_set_user_tag ((CamelMessageInfo *) mi, tag->name, tag->value);
 		tag = tag->next;
 	}
 
-	mi->size = camel_message_info_size(info);
+	mi->size = camel_message_info_size (info);
 	mi->uid = camel_pstring_strdup (uid);
-	camel_folder_summary_add (summary, (CamelMessageInfo *)mi);
+	camel_folder_summary_add (summary, (CamelMessageInfo *) mi);
 }
 
 /**
@@ -596,13 +588,13 @@ camel_exchange_summary_add_offline (CamelFolderSummary *summary,
  **/
 void
 camel_exchange_summary_add_offline_uncached (CamelFolderSummary *summary,
-					     const gchar *uid,
-					     CamelMessageInfo *info)
+                                             const gchar *uid,
+                                             CamelMessageInfo *info)
 {
 	CamelMessageInfo *mi;
 
 	/* Create summary entry */
-	mi = camel_message_info_clone(info);
+	mi = camel_message_info_clone (info);
 
 	/* Set uid and add to summary */
 	mi->uid = camel_pstring_strdup (uid);
