@@ -39,10 +39,7 @@ exchange_transport_send_to_sync (CamelTransport *transport,
                                  GCancellable *cancellable,
                                  GError **error)
 {
-	CamelService *service;
-	CamelSession *session;
 	CamelStore *store = NULL;
-	gchar *url_string;
 	CamelInternetAddress *cia;
 	const gchar *addr;
 	GPtrArray *recipients_array;
@@ -55,25 +52,6 @@ exchange_transport_send_to_sync (CamelTransport *transport,
 	GSList *h, *bcc = NULL;
 	gint len, i;
 
-	service = CAMEL_SERVICE (transport);
-	session = camel_service_get_session (service);
-
-	url_string = camel_session_get_password (
-		session, service, NULL,
-		"ignored", "popb4smtp_uri", 0, error);
-	if (!url_string)
-		return FALSE;
-	if (strncmp (url_string, "exchange:", 9) != 0) {
-		g_set_error (
-			error, CAMEL_SERVICE_ERROR,
-			CAMEL_SERVICE_ERROR_UNAVAILABLE,
-			_("Exchange transport can only be used with Exchange mail source"));
-		g_free (url_string);
-		return FALSE;
-	}
-
-	g_free (url_string);
-
 	recipients_array = g_ptr_array_new ();
 	len = camel_address_length (recipients);
 	cia = CAMEL_INTERNET_ADDRESS (recipients);
@@ -85,7 +63,7 @@ exchange_transport_send_to_sync (CamelTransport *transport,
 			g_ptr_array_free (recipients_array, TRUE);
 			return FALSE;
 		}
-		g_ptr_array_add (recipients_array, (gchar *)addr);
+		g_ptr_array_add (recipients_array, (gchar *) addr);
 	}
 
 	if (!camel_internet_address_get (CAMEL_INTERNET_ADDRESS (from), 0, NULL, &addr)) {
