@@ -25,6 +25,7 @@
 #include <config.h>
 #endif
 
+#include "camel-exchange-settings.h"
 #include "exchange-account.h"
 #include "exchange-hierarchy-webdav.h"
 #include "exchange-hierarchy-favorites.h"
@@ -54,6 +55,10 @@
 #define ONE_HUNDRED_NANOSECOND 0.000000100
 #define SECONDS_IN_DAY 86400
 
+#define EXCHANGE_ACCOUNT_GET_PRIVATE(obj) \
+	(G_TYPE_INSTANCE_GET_PRIVATE \
+	((obj), EXCHANGE_TYPE_ACCOUNT, ExchangeAccountPrivate))
+
 struct _ExchangeAccountPrivate {
 	E2kContext *ctx;
 	E2kGlobalCatalog *gc;
@@ -70,17 +75,16 @@ struct _ExchangeAccountPrivate {
 	GHashTable *folders;
 	GStaticRecMutex folders_lock;
 	gchar *uri_authority, *http_uri_schema;
-	gboolean uris_use_email, offline_sync;
+	gboolean uris_use_email;
 
 	gchar *identity_name, *identity_email, *source_uri, *password_key;
-	gchar *username, *password, *windows_domain, *nt_domain, *ad_server;
-	gchar *owa_url;
+	gchar *username, *password, *windows_domain, *nt_domain;
 	E2kAutoconfigAuthPref auth_pref;
-	gint ad_limit, passwd_exp_warn_period, quota_limit;
-	E2kAutoconfigGalAuthPref ad_auth;
+	gint quota_limit;
 
 	EAccountList *account_list;
 	EAccount *account;
+	CamelSettings *settings;
 
 	GMutex *discover_data_lock;
 	GList *discover_datas;
@@ -109,6 +113,8 @@ exchange_account_class_init (ExchangeAccountClass *class)
 {
 	GObjectClass *object_class;
 
+	g_type_class_add_private (class, sizeof (ExchangeAccountPrivate));
+
 	object_class = G_OBJECT_CLASS (class);
 	object_class->dispose = dispose;
 	object_class->finalize = finalize;
@@ -146,7 +152,7 @@ exchange_account_class_init (ExchangeAccountClass *class)
 static void
 exchange_account_init (ExchangeAccount *account)
 {
-	account->priv = g_new0 (ExchangeAccountPrivate, 1);
+	account->priv = EXCHANGE_ACCOUNT_GET_PRIVATE (account);
 	account->priv->connect_lock = g_mutex_new ();
 	account->priv->hierarchies = g_ptr_array_new ();
 	account->priv->hierarchies_by_folder = g_hash_table_new (NULL, NULL);
@@ -160,13 +166,17 @@ exchange_account_init (ExchangeAccount *account)
 }
 
 static void
-free_name (gpointer name, gpointer value, gpointer data)
+free_name (gpointer name,
+           gpointer value,
+           gpointer data)
 {
 	g_free (name);
 }
 
 static void
-free_folder (gpointer key, gpointer folder, gpointer data)
+free_folder (gpointer key,
+             gpointer folder,
+             gpointer data)
 {
 	g_object_unref (folder);
 }
@@ -174,62 +184,71 @@ free_folder (gpointer key, gpointer folder, gpointer data)
 static void
 dispose (GObject *object)
 {
-	ExchangeAccount *account = EXCHANGE_ACCOUNT (object);
+	ExchangeAccountPrivate *priv;
 	gint i;
 
-	if (account->priv->account) {
-		g_object_unref (account->priv->account);
-		account->priv->account = NULL;
+	priv = EXCHANGE_ACCOUNT_GET_PRIVATE (object);
+
+	if (priv->account) {
+		g_object_unref (priv->account);
+		priv->account = NULL;
 	}
 
-	if (account->priv->account_list) {
-		g_object_unref (account->priv->account_list);
-		account->priv->account_list = NULL;
+	if (priv->account_list) {
+		g_object_unref (priv->account_list);
+		priv->account_list = NULL;
 	}
 
-	if (account->priv->ctx) {
-		g_object_unref (account->priv->ctx);
-		account->priv->ctx = NULL;
+	if (priv->settings) {
+		g_object_unref (priv->settings);
+		priv->settings = NULL;
 	}
 
-	if (account->priv->gc) {
-		g_object_unref (account->priv->gc);
-		account->priv->gc = NULL;
+	if (priv->ctx) {
+		g_object_unref (priv->ctx);
+		priv->ctx = NULL;
 	}
 
-	if (account->priv->hierarchies) {
-		for (i = 0; i < account->priv->hierarchies->len; i++)
-			g_object_unref (account->priv->hierarchies->pdata[i]);
-		g_ptr_array_free (account->priv->hierarchies, TRUE);
-		account->priv->hierarchies = NULL;
+	if (priv->gc) {
+		g_object_unref (priv->gc);
+		priv->gc = NULL;
 	}
 
-	if (account->priv->foreign_hierarchies) {
-		g_hash_table_foreach (account->priv->foreign_hierarchies, free_name, NULL);
-		g_hash_table_destroy (account->priv->foreign_hierarchies);
-		account->priv->foreign_hierarchies = NULL;
+	if (priv->hierarchies) {
+		for (i = 0; i < priv->hierarchies->len; i++)
+			g_object_unref (priv->hierarchies->pdata[i]);
+		g_ptr_array_free (priv->hierarchies, TRUE);
+		priv->hierarchies = NULL;
 	}
 
-	g_static_rec_mutex_lock (&account->priv->folders_lock);
-
-	if (account->priv->hierarchies_by_folder) {
-		g_hash_table_destroy (account->priv->hierarchies_by_folder);
-		account->priv->hierarchies_by_folder = NULL;
+	if (priv->foreign_hierarchies) {
+		g_hash_table_foreach (priv->foreign_hierarchies, free_name, NULL);
+		g_hash_table_destroy (priv->foreign_hierarchies);
+		priv->foreign_hierarchies = NULL;
 	}
 
-	if (account->priv->folders) {
-		g_hash_table_foreach (account->priv->folders, free_folder, NULL);
-		g_hash_table_destroy (account->priv->folders);
-		account->priv->folders = NULL;
+	g_static_rec_mutex_lock (&priv->folders_lock);
+
+	if (priv->hierarchies_by_folder) {
+		g_hash_table_destroy (priv->hierarchies_by_folder);
+		priv->hierarchies_by_folder = NULL;
 	}
 
-	g_static_rec_mutex_unlock (&account->priv->folders_lock);
+	if (priv->folders) {
+		g_hash_table_foreach (priv->folders, free_folder, NULL);
+		g_hash_table_destroy (priv->folders);
+		priv->folders = NULL;
+	}
+
+	g_static_rec_mutex_unlock (&priv->folders_lock);
 
 	G_OBJECT_CLASS (exchange_account_parent_class)->dispose (object);
 }
 
 static void
-free_uri (gpointer name, gpointer uri, gpointer data)
+free_uri (gpointer name,
+          gpointer uri,
+          gpointer data)
 {
 	g_free (name);
 	g_free (uri);
@@ -288,12 +307,6 @@ finalize (GObject *object)
 	if (account->priv->nt_domain)
 		g_free (account->priv->nt_domain);
 
-	if (account->priv->ad_server)
-		g_free (account->priv->ad_server);
-
-	if (account->priv->owa_url)
-		g_free (account->priv->owa_url);
-
 	if (account->priv->connect_lock)
 		g_mutex_free (account->priv->connect_lock);
 
@@ -302,8 +315,6 @@ finalize (GObject *object)
 
 	g_static_rec_mutex_free (&account->priv->folders_lock);
 
-	g_free (account->priv);
-
 	G_OBJECT_CLASS (exchange_account_parent_class)->finalize (object);
 }
 
@@ -333,8 +344,9 @@ exchange_account_rescan_tree (ExchangeAccount *account)
  */
 
 static void
-hierarchy_new_folder (ExchangeHierarchy *hier, EFolder *folder,
-		      ExchangeAccount *account)
+hierarchy_new_folder (ExchangeHierarchy *hier,
+                      EFolder *folder,
+                      ExchangeAccount *account)
 {
 	gint table_updated = 0;
 	const gchar *permanent_uri =
@@ -371,8 +383,8 @@ hierarchy_new_folder (ExchangeHierarchy *hier, EFolder *folder,
 	key = (gchar *) e_folder_exchange_get_internal_uri (folder);
 	if (!g_hash_table_lookup (account->priv->folders, key)) {
 		/* The internal_uri for public folders and favorites folder
-		   is same !!! Without this check the folder value could
-		   overwrite the previously added folder. */
+		 * is same !!! Without this check the folder value could
+		 * overwrite the previously added folder. */
 		g_object_ref (folder);
 		g_hash_table_insert (account->priv->folders,
 				     key,
@@ -402,8 +414,9 @@ hierarchy_new_folder (ExchangeHierarchy *hier, EFolder *folder,
 }
 
 static void
-hierarchy_removed_folder (ExchangeHierarchy *hier, EFolder *folder,
-			  ExchangeAccount *account)
+hierarchy_removed_folder (ExchangeHierarchy *hier,
+                          EFolder *folder,
+                          ExchangeAccount *account)
 {
 	gint unref_count = 0;
 
@@ -443,8 +456,10 @@ hierarchy_removed_folder (ExchangeHierarchy *hier, EFolder *folder,
 }
 
 static gboolean
-get_folder (ExchangeAccount *account, const gchar *path,
-	    EFolder **folder, ExchangeHierarchy **hier)
+get_folder (ExchangeAccount *account,
+            const gchar *path,
+            EFolder **folder,
+            ExchangeHierarchy **hier)
 {
 	g_static_rec_mutex_lock (&account->priv->folders_lock);
 	*folder = g_hash_table_lookup (account->priv->folders, path);
@@ -461,8 +476,10 @@ get_folder (ExchangeAccount *account, const gchar *path,
 }
 
 static gboolean
-get_parent_and_name (ExchangeAccount *account, const gchar **path,
-		     EFolder **parent, ExchangeHierarchy **hier)
+get_parent_and_name (ExchangeAccount *account,
+                     const gchar **path,
+                     EFolder **parent,
+                     ExchangeHierarchy **hier)
 {
 	gchar *name, *parent_path;
 
@@ -492,7 +509,8 @@ get_parent_and_name (ExchangeAccount *account, const gchar **path,
 
 ExchangeAccountFolderResult
 exchange_account_create_folder (ExchangeAccount *account,
-				const gchar *path, const gchar *type)
+                                const gchar *path,
+                                const gchar *type)
 {
 	ExchangeHierarchy *hier;
 	EFolder *parent;
@@ -507,7 +525,9 @@ exchange_account_create_folder (ExchangeAccount *account,
 }
 
 static gboolean
-check_if_sf (gpointer key, gpointer value, gpointer user_data)
+check_if_sf (gpointer key,
+             gpointer value,
+             gpointer user_data)
 {
 	gchar *sf_href = (gchar *) value;
 	gchar *int_uri = (gchar *) user_data;
@@ -519,7 +539,8 @@ check_if_sf (gpointer key, gpointer value, gpointer user_data)
 }
 
 ExchangeAccountFolderResult
-exchange_account_remove_folder (ExchangeAccount *account, const gchar *path)
+exchange_account_remove_folder (ExchangeAccount *account,
+                                const gchar *path)
 {
 	ExchangeHierarchy *hier;
 	EFolder *folder;
@@ -545,9 +566,9 @@ exchange_account_remove_folder (ExchangeAccount *account, const gchar *path)
 
 ExchangeAccountFolderResult
 exchange_account_xfer_folder (ExchangeAccount *account,
-			      const gchar *source_path,
-			      const gchar *dest_path,
-			      gboolean remove_source)
+                              const gchar *source_path,
+                              const gchar *dest_path,
+                              gboolean remove_source)
 {
 	EFolder *source, *dest_parent;
 	ExchangeHierarchy *source_hier, *dest_hier;
@@ -578,7 +599,8 @@ exchange_account_xfer_folder (ExchangeAccount *account,
 }
 
 static void
-remove_hierarchy (ExchangeAccount *account, ExchangeHierarchy *hier)
+remove_hierarchy (ExchangeAccount *account,
+                  ExchangeHierarchy *hier)
 {
 	gint i;
 
@@ -596,7 +618,8 @@ remove_hierarchy (ExchangeAccount *account, ExchangeHierarchy *hier)
 }
 
 static void
-setup_hierarchy (ExchangeAccount *account, ExchangeHierarchy *hier)
+setup_hierarchy (ExchangeAccount *account,
+                 ExchangeHierarchy *hier)
 {
 	g_ptr_array_add (account->priv->hierarchies, hier);
 
@@ -609,7 +632,8 @@ setup_hierarchy (ExchangeAccount *account, ExchangeHierarchy *hier)
 }
 
 static void
-setup_hierarchy_foreign (ExchangeAccount *account, ExchangeHierarchy *hier)
+setup_hierarchy_foreign (ExchangeAccount *account,
+                         ExchangeHierarchy *hier)
 {
 	g_hash_table_insert (account->priv->foreign_hierarchies,
 			     (gchar *) hier->owner_email, hier);
@@ -622,7 +646,8 @@ struct discover_data {
 };
 
 static ExchangeHierarchy *
-get_hierarchy_for (ExchangeAccount *account, E2kGlobalCatalogEntry *entry)
+get_hierarchy_for (ExchangeAccount *account,
+                   E2kGlobalCatalogEntry *entry)
 {
 	ExchangeHierarchy *hier;
 	gchar *hierarchy_name, *source;
@@ -634,7 +659,7 @@ get_hierarchy_for (ExchangeAccount *account, E2kGlobalCatalogEntry *entry)
 		return hier;
 
 	/* i18n: This is the title of an "other user's folders"
-	   hierarchy. Eg, "John Doe's Folders". */
+	 * hierarchy. Eg, "John Doe's Folders". */
 	hierarchy_name = g_strdup_printf (_("%s's Folders"),
 					  entry->display_name);
 	source = g_strdup_printf ("exchange://%s@%s/", entry->mailbox,
@@ -661,9 +686,9 @@ get_hierarchy_for (ExchangeAccount *account, E2kGlobalCatalogEntry *entry)
 
 ExchangeAccountFolderResult
 exchange_account_discover_shared_folder (ExchangeAccount *account,
-					 const gchar *user,
-					 const gchar *folder_name,
-					 EFolder **folder)
+                                         const gchar *user,
+                                         const gchar *folder_name,
+                                         EFolder **folder)
 {
 	struct discover_data dd;
 	ExchangeHierarchy *hier;
@@ -726,8 +751,8 @@ exchange_account_discover_shared_folder (ExchangeAccount *account,
 
 void
 exchange_account_cancel_discover_shared_folder (ExchangeAccount *account,
-						const gchar *user,
-						const gchar *folder_name)
+                                                const gchar *user,
+                                                const gchar *folder_name)
 {
 	struct discover_data *dd;
 	GList *dds;
@@ -760,7 +785,7 @@ exchange_account_cancel_discover_shared_folder (ExchangeAccount *account,
 
 ExchangeAccountFolderResult
 exchange_account_remove_shared_folder (ExchangeAccount *account,
-				       const gchar *path)
+                                       const gchar *path)
 {
 	ExchangeHierarchy *hier;
 	EFolder *folder;
@@ -777,7 +802,8 @@ exchange_account_remove_shared_folder (ExchangeAccount *account,
 }
 
 ExchangeAccountFolderResult
-exchange_account_open_folder (ExchangeAccount *account, const gchar *path)
+exchange_account_open_folder (ExchangeAccount *account,
+                              const gchar *path)
 {
 	ExchangeHierarchy *hier;
 	EFolder *folder;
@@ -807,7 +833,7 @@ exchange_account_open_folder (ExchangeAccount *account, const gchar *path)
 
 ExchangeAccountFolderResult
 exchange_account_add_favorite (ExchangeAccount *account,
-			       EFolder         *folder)
+                               EFolder *folder)
 {
 	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR);
 	g_return_val_if_fail (E_IS_FOLDER (folder), EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR);
@@ -819,7 +845,7 @@ exchange_account_add_favorite (ExchangeAccount *account,
 
 ExchangeAccountFolderResult
 exchange_account_remove_favorite (ExchangeAccount *account,
-				  EFolder         *folder)
+                                  EFolder *folder)
 {
 	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR);
 	g_return_val_if_fail (E_IS_FOLDER (folder), EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR);
@@ -831,7 +857,7 @@ exchange_account_remove_favorite (ExchangeAccount *account,
 
 gboolean
 exchange_account_is_favorite_folder (ExchangeAccount *account,
-					EFolder         *folder)
+                                     EFolder *folder)
 {
 	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR);
 	g_return_val_if_fail (E_IS_FOLDER (folder), EXCHANGE_ACCOUNT_FOLDER_GENERIC_ERROR);
@@ -842,9 +868,11 @@ exchange_account_is_favorite_folder (ExchangeAccount *account,
 }
 
 static void
-context_redirect (E2kContext *ctx, E2kHTTPStatus status,
-		  const gchar *old_uri, const gchar *new_uri,
-		  ExchangeAccount *account)
+context_redirect (E2kContext *ctx,
+                  E2kHTTPStatus status,
+                  const gchar *old_uri,
+                  const gchar *new_uri,
+                  ExchangeAccount *account)
 {
 	EFolder *folder;
 
@@ -865,8 +893,10 @@ context_redirect (E2kContext *ctx, E2kHTTPStatus status,
 }
 
 static void
-set_sf_prop (const gchar *propname, E2kPropType type,
-	     gpointer phref, gpointer user_data)
+set_sf_prop (const gchar *propname,
+             E2kPropType type,
+             gpointer phref,
+             gpointer user_data)
 {
 	ExchangeAccount *account = user_data;
 	const gchar *href = (const gchar *) phref;
@@ -907,7 +937,8 @@ static const gchar *mailbox_info_props[] = {
 static const gint n_mailbox_info_props = G_N_ELEMENTS (mailbox_info_props);
 
 static gboolean
-account_moved (ExchangeAccount *account, E2kAutoconfig *ac)
+account_moved (ExchangeAccount *account,
+               E2kAutoconfig *ac)
 {
 	E2kAutoconfigResult result;
 	EAccount *eaccount;
@@ -936,7 +967,9 @@ account_moved (ExchangeAccount *account, E2kAutoconfig *ac)
 
 #if 0
 static gboolean
-get_password (ExchangeAccount *account, E2kAutoconfig *ac, ExchangeAccountResult error)
+get_password (ExchangeAccount *account,
+              E2kAutoconfig *ac,
+              ExchangeAccountResult error)
 {
 	gchar *password;
 
@@ -959,7 +992,7 @@ get_password (ExchangeAccount *account, E2kAutoconfig *ac, ExchangeAccountResult
 					NULL,
 					account->priv->password_key,
 					prompt,
-					E_PASSWORDS_REMEMBER_FOREVER|E_PASSWORDS_SECRET,
+					E_PASSWORDS_REMEMBER_FOREVER | E_PASSWORDS_SECRET,
 					&remember,
 					NULL);
 			if (remember != oldremember) {
@@ -1002,7 +1035,8 @@ get_password (ExchangeAccount *account, E2kAutoconfig *ac, ExchangeAccountResult
  */
 #ifdef HAVE_KRB5
 static gboolean
-is_password_expired (ExchangeAccount *account, E2kAutoconfig *ac)
+is_password_expired (ExchangeAccount *account,
+                     E2kAutoconfig *ac)
 {
 	gchar *domain;
 	E2kKerberosResult result;
@@ -1036,37 +1070,49 @@ is_password_expired (ExchangeAccount *account, E2kAutoconfig *ac)
 #endif
 
 static gint
-find_passwd_exp_period (ExchangeAccount *account, E2kGlobalCatalogEntry *entry)
+find_passwd_exp_period (ExchangeAccount *account,
+                        E2kGlobalCatalogEntry *entry)
 {
 	gdouble max_pwd_age = 0;
 	gint max_pwd_age_days;
 	E2kOperation gcop;
+	CamelSettings *settings;
 	E2kGlobalCatalogStatus gcstatus;
+	gboolean use_passwd_exp_warn_period;
+	guint passwd_exp_warn_period;
+
+	settings = exchange_account_get_settings (account);
+
+	g_object_get (
+		settings,
+		"passwd-exp-warn-period", &passwd_exp_warn_period,
+		"use-passwd-exp-warn-period", &use_passwd_exp_warn_period,
+		NULL);
 
 	/* If user has not selected password expiry warning option, return */
-	if (account->priv->passwd_exp_warn_period == -1)
+	if (!use_passwd_exp_warn_period)
 		return -1;
 
 	/* Check for password expiry period */
 	/* This needs to be invoked after is_password_expired(), i.e.,
-	   only if password is not expired */
+	 * only if password is not expired */
 
 	/* Check for account control value for a user */
 
 	e2k_operation_init (&gcop);
-	gcstatus = e2k_global_catalog_lookup (account->priv->gc,
-					      &gcop,
-					      E2K_GLOBAL_CATALOG_LOOKUP_BY_EMAIL,
-					      account->priv->identity_email,
-					      E2K_GLOBAL_CATALOG_LOOKUP_ACCOUNT_CONTROL,
-					      &entry);
+	gcstatus = e2k_global_catalog_lookup (
+		account->priv->gc, &gcop,
+		E2K_GLOBAL_CATALOG_LOOKUP_BY_EMAIL,
+		account->priv->identity_email,
+		E2K_GLOBAL_CATALOG_LOOKUP_ACCOUNT_CONTROL,
+		&entry);
 	e2k_operation_free (&gcop);
+
 	if (gcstatus != E2K_GLOBAL_CATALOG_OK)
 		return -1;
 
-	if (entry->user_account_control & ADS_UF_DONT_EXPIRE_PASSWORD) {
+	if (entry->user_account_control & ADS_UF_DONT_EXPIRE_PASSWORD)
 		return -1;         /* Password is not set to expire */
-	}
 
 	/* Here we don't check not setting the password and expired password */
 	/* Check for the maximum password age set */
@@ -1078,12 +1124,12 @@ find_passwd_exp_period (ExchangeAccount *account, E2kGlobalCatalogEntry *entry)
 	if (max_pwd_age > 0) {
 		/* Calculate password expiry period */
 		max_pwd_age_days =
-		( max_pwd_age * ONE_HUNDRED_NANOSECOND ) / SECONDS_IN_DAY;
+		(max_pwd_age * ONE_HUNDRED_NANOSECOND) / SECONDS_IN_DAY;
 
-		if (max_pwd_age_days <= account->priv->passwd_exp_warn_period) {
+		if (max_pwd_age_days <= passwd_exp_warn_period)
 			return max_pwd_age_days;
-		}
 	}
+
 	return -1;
 }
 
@@ -1100,7 +1146,9 @@ exchange_account_forget_password (ExchangeAccount *account)
 }
 
 ExchangeAccountResult
-exchange_account_set_password (ExchangeAccount *account, gchar *old_pass, gchar *new_pass)
+exchange_account_set_password (ExchangeAccount *account,
+                               gchar *old_pass,
+                               gchar *new_pass)
 {
 #ifdef HAVE_KRB5
 	E2kKerberosResult result;
@@ -1155,7 +1203,8 @@ exchange_account_set_password (ExchangeAccount *account, gchar *old_pass, gchar
 }
 
 void
-exchange_account_set_save_password (ExchangeAccount *account, gboolean save_password)
+exchange_account_set_save_password (ExchangeAccount *account,
+                                    gboolean save_password)
 {
 	account->priv->account->source->save_passwd = save_password;
 }
@@ -1224,7 +1273,8 @@ exchange_account_set_online (ExchangeAccount *account)
  * Return value: Returns TRUE if account is offline
  **/
 void
-exchange_account_is_offline (ExchangeAccount *account, gint *state)
+exchange_account_is_offline (ExchangeAccount *account,
+                             gint *state)
 {
 	g_return_if_fail (EXCHANGE_IS_ACCOUNT (account));
 
@@ -1368,8 +1418,9 @@ hierarchies_created:
  * failed.
  **/
 E2kContext *
-exchange_account_connect (ExchangeAccount *account, const gchar *pword,
-			  ExchangeAccountResult *info_result)
+exchange_account_connect (ExchangeAccount *account,
+                          const gchar *pword,
+                          ExchangeAccountResult *info_result)
 {
 	E2kAutoconfig *ac;
 	E2kAutoconfigResult result;
@@ -1384,6 +1435,10 @@ exchange_account_connect (ExchangeAccount *account, const gchar *pword,
 	E2kOperation gcop;
 	gchar *user_name = NULL;
 	gboolean tried_ntlm = FALSE, tried_basic = FALSE;
+	gchar *gc_server_name;
+	gint gc_results_limit;
+	gboolean use_gc_results_limit;
+	E2kAutoconfigGalAuthPref gc_auth_method;
 
 	*info_result = EXCHANGE_ACCOUNT_UNKNOWN_ERROR;
 	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), NULL);
@@ -1428,8 +1483,21 @@ exchange_account_connect (ExchangeAccount *account, const gchar *pword,
 				 account->priv->auth_pref);
 	g_free (user_name);
 
-	e2k_autoconfig_set_gc_server (ac, account->priv->ad_server,
-				      account->priv->ad_limit, account->priv->ad_auth);
+	g_object_get (
+		account->priv->settings,
+		"gc-auth-method", &gc_auth_method,
+		"gc-results-limit", &gc_results_limit,
+		"gc-server-name", &gc_server_name,
+		"use-gc-results-limit", &use_gc_results_limit,
+		NULL);
+
+	if (!use_gc_results_limit)
+		gc_results_limit = -1;  /* unlimited */
+
+	e2k_autoconfig_set_gc_server (
+		ac, gc_server_name, gc_results_limit, gc_auth_method);
+
+	g_free (gc_server_name);
 
 	if (!pword) {
 		account->priv->connecting = FALSE;
@@ -1639,16 +1707,21 @@ skip_quota:
  * Return value: TRUE if offline_sync is set for @account and FALSE if not.
  */
 void
-exchange_account_is_offline_sync_set (ExchangeAccount *account, gint *mode)
+exchange_account_is_offline_sync_set (ExchangeAccount *account,
+                                      gint *mode)
 {
+	CamelSettings *settings;
+	gboolean stay_synchronized;
 	*mode = UNSUPPORTED_MODE;
 
 	g_return_if_fail (EXCHANGE_IS_ACCOUNT (account));
 
-	if (account->priv->offline_sync)
-		*mode = OFFLINE_MODE;
-	else
-		*mode = ONLINE_MODE;
+	settings = exchange_account_get_settings (account);
+
+	stay_synchronized = camel_offline_settings_get_stay_synchronized (
+		CAMEL_OFFLINE_SETTINGS (settings));
+
+	*mode = stay_synchronized ? OFFLINE_MODE : ONLINE_MODE;
 }
 
 /**
@@ -1681,6 +1754,21 @@ exchange_account_get_global_catalog (ExchangeAccount *account)
 	return account->priv->gc;
 }
 
+/**
+ * exchange_account_get_settings:
+ * @account: an #ExchangeAccount
+ *
+ * Return value: @account's #CamelSettings, created from the #EAccount
+ * given in exchange_account_new().
+ **/
+CamelSettings *
+exchange_account_get_settings (ExchangeAccount *account)
+{
+	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), NULL);
+
+	return account->priv->settings;
+}
+
 /**
  * exchange_account_fetch:
  * @acct: an #ExchangeAccount
@@ -1696,37 +1784,6 @@ exchange_account_fetch (ExchangeAccount *acct)
 	return acct->priv->account;
 }
 
-/**
- * exchange_account_get_account_uri_param:
- * @acct: and #ExchangeAccount
- * @param: uri param name to get
- *
- * Reads the parameter #param from the source url of the underlying EAccount.
- * Returns the value or NULL. Returned value should be freed with g_free.
- **/
-gchar *
-exchange_account_get_account_uri_param (ExchangeAccount *acct, const gchar *param)
-{
-	EAccount *account;
-	E2kUri *uri;
-	gchar *res;
-
-	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (acct), NULL);
-	g_return_val_if_fail (param != NULL, NULL);
-
-	account = exchange_account_fetch (acct);
-	g_return_val_if_fail (account != NULL, NULL);
-
-	uri = e2k_uri_new (e_account_get_string (account, E_ACCOUNT_SOURCE_URL));
-	g_return_val_if_fail (uri != NULL, NULL);
-
-	res = g_strdup (e2k_uri_get_param (uri, param));
-
-	e2k_uri_free (uri);
-
-	return res;
-}
-
 /**
  * exchange_account_get_standard_uri:
  * @account: an #ExchangeAccount
@@ -1743,7 +1800,8 @@ exchange_account_get_account_uri_param (ExchangeAccount *acct, const gchar *para
  * defined on @account.
  **/
 const gchar *
-exchange_account_get_standard_uri (ExchangeAccount *account, const gchar *item)
+exchange_account_get_standard_uri (ExchangeAccount *account,
+                                   const gchar *item)
 {
 	g_return_val_if_fail (EXCHANGE_IS_ACCOUNT (account), NULL);
 
@@ -1766,8 +1824,8 @@ exchange_account_get_standard_uri (ExchangeAccount *account, const gchar *item)
  **/
 gchar *
 exchange_account_get_standard_uri_for (ExchangeAccount *account,
-				       const gchar *home_uri,
-				       const gchar *std_uri_prop)
+                                       const gchar *home_uri,
+                                       const gchar *std_uri_prop)
 {
 	gchar *foreign_uri, *prop;
 	E2kHTTPStatus status;
@@ -1810,8 +1868,8 @@ exchange_account_get_standard_uri_for (ExchangeAccount *account,
  **/
 gchar *
 exchange_account_get_foreign_uri (ExchangeAccount *account,
-				  E2kGlobalCatalogEntry *entry,
-				  const gchar *std_uri_prop)
+                                  E2kGlobalCatalogEntry *entry,
+                                  const gchar *std_uri_prop)
 {
 	gchar *home_uri, *foreign_uri;
 
@@ -1845,7 +1903,8 @@ exchange_account_get_foreign_uri (ExchangeAccount *account,
   problem between exchange and evolution is fixed. Exchange does not get to know
  if an user's folder is subscribed from evolution */
 void
-exchange_account_scan_foreign_hierarchy (ExchangeAccount *account, const gchar *user_email)
+exchange_account_scan_foreign_hierarchy (ExchangeAccount *account,
+                                         const gchar *user_email)
 {
 	gchar *dir;
 	ExchangeHierarchy *hier;
@@ -1881,7 +1940,8 @@ exchange_account_scan_foreign_hierarchy (ExchangeAccount *account, const gchar *
  **/
 
 ExchangeHierarchy *
-exchange_account_get_hierarchy_by_email (ExchangeAccount *account, const gchar *email)
+exchange_account_get_hierarchy_by_email (ExchangeAccount *account,
+                                         const gchar *email)
 {
 	gchar *dir;
 	ExchangeHierarchy *hier = NULL;
@@ -1944,7 +2004,7 @@ exchange_account_get_sanitized_path (const gchar *uri)
  **/
 EFolder *
 exchange_account_get_folder (ExchangeAccount *account,
-			     const gchar *path_or_uri)
+                             const gchar *path_or_uri)
 {
 	EFolder *folder;
 
@@ -1960,7 +2020,8 @@ exchange_account_get_folder (ExchangeAccount *account,
 }
 
 static gint
-folder_comparator (gconstpointer a, gconstpointer b)
+folder_comparator (gconstpointer a,
+                   gconstpointer b)
 {
 	EFolder **fa = (EFolder **) a;
 	EFolder **fb = (EFolder **) b;
@@ -1975,7 +2036,9 @@ struct _folders_tree {
 };
 
 static void
-add_folder (gpointer key, gpointer value, gpointer folders)
+add_folder (gpointer key,
+            gpointer value,
+            gpointer folders)
 {
 	EFolder *folder = value;
 
@@ -1991,7 +2054,9 @@ add_folder (gpointer key, gpointer value, gpointer folders)
 }
 
 static void
-add_folder_tree (gpointer key, gpointer value, gpointer folders)
+add_folder_tree (gpointer key,
+                 gpointer value,
+                 gpointer folders)
 {
 	EFolder *folder = value;
 	struct _folders_tree *fld_tree = (struct _folders_tree *) folders;
@@ -2046,7 +2111,8 @@ exchange_account_get_folders (ExchangeAccount *account)
  * g_ptr_array_free().
  **/
 GPtrArray *
-exchange_account_get_folder_tree (ExchangeAccount *account, gchar * path)
+exchange_account_get_folder_tree (ExchangeAccount *account,
+                                  gchar *path)
 {
 	GPtrArray *folders = NULL;
 	EFolder *folder = NULL;
@@ -2158,8 +2224,8 @@ exchange_account_get_email_id (ExchangeAccount *account)
   **/
 void
 exchange_account_folder_size_add (ExchangeAccount *account,
-				     const gchar *folder_name,
-				     gdouble size)
+                                  const gchar *folder_name,
+                                  gdouble size)
 {
 	g_return_if_fail (EXCHANGE_IS_ACCOUNT (account));
 
@@ -2177,7 +2243,7 @@ exchange_account_folder_size_add (ExchangeAccount *account,
   **/
 void
 exchange_account_folder_size_remove (ExchangeAccount *account,
-					const gchar *folder_name)
+                                     const gchar *folder_name)
 {
 	g_return_if_fail (EXCHANGE_IS_ACCOUNT (account));
 
@@ -2197,8 +2263,8 @@ exchange_account_folder_size_remove (ExchangeAccount *account,
   **/
 void
 exchange_account_folder_size_rename (ExchangeAccount *account,
-					const gchar *old_name,
-					const gchar *new_name)
+                                     const gchar *old_name,
+                                     const gchar *new_name)
 {
 	gdouble cached_size;
 
@@ -2253,14 +2319,16 @@ exchange_account_get_authtype (ExchangeAccount *account)
  * Return value: a new #ExchangeAccount corresponding to @adata
  **/
 ExchangeAccount *
-exchange_account_new (EAccountList *account_list, EAccount *adata)
+exchange_account_new (EAccountList *account_list,
+                      EAccount *adata)
 {
 	ExchangeAccount *account;
 	gchar *enc_user, *mailbox;
-	const gchar *param, *proto="http", *owa_path, *pf_server, *owa_url;
-	const gchar *passwd_exp_warn_period, *offline_sync;
+	const gchar *param, *proto="http", *owa_path, *owa_url;
 	const gchar *user_data_dir;
 	gchar *user_at_host;
+	CamelSettings *settings;
+	CamelURL camel_url;
 	E2kUri *uri;
 
 	uri = e2k_uri_new (adata->source->url);
@@ -2278,6 +2346,17 @@ exchange_account_new (EAccountList *account_list, EAccount *adata)
 	account->priv->account = adata;
 	g_object_ref (adata);
 
+	/* XXX A E2kUri struct is just a CamelURL struct plus a domain
+	 *     field.  Otherwise they're identical.  For the purpose of
+	 *     populating the CamelSettings, we just need to allocate a
+	 *     mock CamelURL struct and point its "params" field to the
+	 *     E2kUri's "params" field. */
+	memset (&camel_url, 0, sizeof (CamelURL));
+	camel_url.params = uri->params;
+	settings = g_object_new (CAMEL_TYPE_EXCHANGE_SETTINGS, NULL);
+	camel_settings_load_from_url (settings, &camel_url);
+	account->priv->settings = settings;
+
 	account->account_name = g_strdup (adata->name);
 
 	user_data_dir = e_get_user_data_dir ();
@@ -2327,55 +2406,18 @@ exchange_account_new (EAccountList *account_list, EAccount *adata)
 		account->priv->auth_pref = E2K_AUTOCONFIG_USE_BASIC;
 	else
 		account->priv->auth_pref = E2K_AUTOCONFIG_USE_NTLM;
-	param = e2k_uri_get_param (uri, "ad_server");
-	if (param && *param) {
-		account->priv->ad_server = g_strdup (param);
-		param = e2k_uri_get_param (uri, "ad_limit");
-		if (param)
-			account->priv->ad_limit = atoi (param);
-		param = e2k_uri_get_param (uri, "ad_auth");
-		if (!param || g_ascii_strcasecmp (param, "default") == 0)
-			account->priv->ad_auth = E2K_AUTOCONFIG_USE_GAL_DEFAULT;
-		else if (g_ascii_strcasecmp (param, "basic") == 0)
-			account->priv->ad_auth = E2K_AUTOCONFIG_USE_GAL_BASIC;
-		else if (g_ascii_strcasecmp (param, "ntlm") == 0)
-			account->priv->ad_auth = E2K_AUTOCONFIG_USE_GAL_NTLM;
-		else
-			account->priv->ad_auth = E2K_AUTOCONFIG_USE_GAL_DEFAULT;
-	}
 
-	passwd_exp_warn_period = e2k_uri_get_param (uri, "passwd_exp_warn_period");
-	if (!passwd_exp_warn_period || !*passwd_exp_warn_period)
-		account->priv->passwd_exp_warn_period = -1;
-	else
-		account->priv->passwd_exp_warn_period = atoi (passwd_exp_warn_period);
-
-	offline_sync = e2k_uri_get_param (uri, "offline_sync");
-	if (!offline_sync)
-		account->priv->offline_sync = FALSE;
-	else
-		account->priv->offline_sync = TRUE;
-
-	owa_path = e2k_uri_get_param (uri, "owa_path");
-	if (!owa_path || !*owa_path)
+	owa_path = camel_exchange_settings_get_owa_path (
+		CAMEL_EXCHANGE_SETTINGS (settings));
+	if (owa_path == NULL)
 		owa_path = "exchange";
 	else if (*owa_path == '/')
 		owa_path++;
 
-	pf_server = e2k_uri_get_param (uri, "pf_server");
-	if (!pf_server || !*pf_server)
-		pf_server = uri->host;
-
-	/* We set protocol reading owa_url, instead of having use_ssl parameter
-	 * because we don't have SSL section anymore in the account creation
-	 * druid and account editor
-	 */
-	/* proto = e2k_uri_get_param (uri, "use_ssl") ? "https" : "http"; */
-
-	owa_url = e2k_uri_get_param (uri, "owa_url");
-	if (owa_url) {
-		account->priv->owa_url = g_strdup (owa_url);
-		if (!strncmp (owa_url, "https:", 6))
+	owa_url = camel_exchange_settings_get_owa_url (
+		CAMEL_EXCHANGE_SETTINGS (settings));
+	if (owa_url != NULL) {
+		if (strncmp (owa_url, "https:", 6) == 0)
 			proto = "https";
 	}
 
@@ -2385,34 +2427,25 @@ exchange_account_new (EAccountList *account_list, EAccount *adata)
 					 proto, uri->port, owa_path);
 		account->public_uri =
 			g_strdup_printf ("%s://%s:%d/public",
-					 proto, pf_server, uri->port);
+					 proto, uri->host, uri->port);
 	} else {
 		account->priv->http_uri_schema =
 			g_strdup_printf ("%s://%%s/%s/%%s/", proto, owa_path);
 		account->public_uri =
-			g_strdup_printf ("%s://%s/public", proto, pf_server);
+			g_strdup_printf ("%s://%s/public", proto, uri->host);
 	}
 
-	param = e2k_uri_get_param (uri, "mailbox");
-	if (!param || !*param)
+	param = camel_exchange_settings_get_mailbox (
+		CAMEL_EXCHANGE_SETTINGS (settings));
+	if (param == NULL)
 		param = uri->user;
 	else if (!g_ascii_strncasecmp (param, account->priv->identity_email, strlen (param)))
 		account->priv->uris_use_email = TRUE;
 	mailbox = e2k_uri_encode (param, TRUE, "/");
-	account->home_uri = g_strdup_printf (account->priv->http_uri_schema,
-					     uri->host, mailbox);
+	account->home_uri = g_strdup_printf (
+		account->priv->http_uri_schema, uri->host, mailbox);
 	g_free (mailbox);
 
-	param = e2k_uri_get_param (uri, "filter");
-	if (param)
-		account->filter_inbox = TRUE;
-	param = e2k_uri_get_param (uri, "filter_junk");
-	if (param)
-		account->filter_junk = TRUE;
-	param = e2k_uri_get_param (uri, "filter_junk_inbox");
-	if (param)
-		account->filter_junk_inbox_only = TRUE;
-
 	e2k_uri_free (uri);
 
 	return account;
@@ -2428,9 +2461,9 @@ exchange_account_new (EAccountList *account_list, EAccount *adata)
  * Return value: Returns the hierarchy pointer for the requested type
  **/
 
-ExchangeHierarchy*
-exchange_account_get_hierarchy_by_type (ExchangeAccount* acct,
-					ExchangeHierarchyType type)
+ExchangeHierarchy *
+exchange_account_get_hierarchy_by_type (ExchangeAccount *acct,
+                                        ExchangeHierarchyType type)
 {
 	gint i;
 
